# ImprovedInputs

Improved Inputs  is  a  library  that can  make  your inputs much easier. For  example, think about yourself creating a  simple  calculator in  python. First, probably you will  show  the  user  all possible operations and  ask  them to  choose  one.With Improved  Inputs(II)  you can  easily create a selection menu. Let's look to it:  
```python  
from  inprovedinputs  import functions as ii  
  
  
...  

ii.ask("select operation",["Addition","Subtraction","Multipication","Division"],True)  

...  
```  
  
  
This code block will  show  you how to  create  a  basic  menu. The  output  will  be:  
```  
-- Select operation  --  
[1]: Addition  
[2]: Subtraction  
[3]: Multipication  
[4]: Division    
```  
  
  
Find more about this  topic  in our  docs.
